/*
 * DRV8251xEVM Firmware 1.0
 *
 * This firmware is loaded on the DRV8251xEVM boards and allows users to
 * control the DRV8251 and DRV8251A devices on the board using the potentiometers.
 *
Copyright (c) 2021 Texas Instruments Incorporated

All rights reserved not granted herein.

Limited License.

Texas Instruments Incorporated grants a world-wide, royalty-free, non-exclusive license under copyrights and patents it now or hereafter owns or controls to make, have made, use, import, offer to sell and sell ("Utilize") this software subject to the terms herein. With respect to the foregoing patent license, such license is granted solely to the extent that any such patent is necessary to Utilize the software alone. The patent license shall not apply to any combinations which include this software, other than combinations with devices manufactured by or for TI ("TI Devices"). No hardware patent is licensed hereunder.

Redistributions must preserve existing copyright notices and reproduce this license (including the above copyright notice and the disclaimer and (if applicable) source code license limitations below) in the documentation and/or other materials provided with the distribution

Redistribution and use in binary form, without modification, are permitted provided that the following conditions are met:

* No reverse engineering, decompilation, or disassembly of this software is permitted with respect to any software provided in binary form.

* any redistribution and use are licensed by TI for use only with TI Devices.

* Nothing shall obligate TI to provide you with source code for the software licensed and provided to you in object code.

If software source code is provided to you, modification and redistribution of the source code are permitted provided that the following conditions are met:

* any redistribution and use of the source code, including any resulting derivative works, are licensed by TI for use only with TI Devices.

* any redistribution and use of any object code compiled from the source code and any resulting derivative works, are licensed by TI for use only with TI Devices.

Neither the name of Texas Instruments Incorporated nor the names of its suppliers may be used to endorse or promote products derived from this software without specific prior written permission.

DISCLAIMER.

THIS SOFTWARE IS PROVIDED BY TI AND TI"S LICENSORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL TI AND TI"S LICENSORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 *
 ****************************************************************************
*  MSP430FR2100 / DRV8251xEVM
*  SW REV 1.0
*
*  Description: Using DRV8251 and DRV8251A Customer EVM, potentiometers "IN1 PWM", and
*  "IN2 PWM" set the duty cycles for the PWM signals to the IN1 and
*  IN2 pins of the DRV8251/A. The VREF potentiometer sets the current regulation current limit.
*
*  Board Function          MSP430FR2100
*  PWM output 1            P1.6 (TB0.1)
*  PWM output 2            P1.7 (TB0.2)
*  Speed Ref1 Pot          P1.0 (A0 in)
*  Speed Ref2 Pot          P1.1 (A1 in)
*  Output current          P1.2 (A2 in)
*  VREF Pot                P1.3 (A3 in)
*  nSTALL indicator        P1.4 (output)
*  Status LED              P2.7 (output)
*  Stall action            P2.0 (input)
******************************************************************************/

#include "msp430FR2100.h"

// Pins
#define SPD_REF_1   BIT0                 // P1.0
#define SPD_REF_2   BIT1                 // P1.1
#define ISENSE      BIT2                 // P1.2
#define VREF        BIT3                 // P1.3
#define STALL_TH    BIT4                 // P1.4
#define nSTALL      BIT5                 // P1.5
#define PWM2        BIT6                 // P1.6
#define PWM1        BIT7                 // P1.7
#define STALL_ACT   BIT0                 // P2.0
#define DEV_ID      BIT1                 // P2.1
#define STATUS_LED  BIT7                 // P2.7

int main(void)
{
  WDTCTL = WDTPW + WDTHOLD;              // Stop watchdog timer

  //FR2xxx, FR4xxx, FR58xx, FR59xx, FR6xxx devices
  // Configure one FRAM waitstate as required by the device datasheet for MCLK
  // operation beyond 8MHz _before_ configuring the clock system.

  FRCTL0 = FWPW | NWAITS_1; // Change the NACCESS_x value to add the right amount of waitstates, FWPW is the FRAM write password
  __delay_cycles(100);

  CSCTL1 = DCORSEL_5;                     // System Clock set to 16 MHz

  // Configure Pins
  P1OUT = 0x00;                          // P1.x Reset - outputs low
  P2OUT = 0x00;                          // P2.x reset - outputs low
  P1DIR |= PWM1 + PWM2;                  // PWM outputs
  P2DIR = STATUS_LED;                    // Status LED output
  P1SEL0 |= SPD_REF_1 + SPD_REF_2;
  P1SEL1 |= SPD_REF_1 + SPD_REF_2 + PWM1 + PWM2;

  // Disable the GPIO power-on default high-impedance mode to activate
  // previously configured port settings
  PM5CTL0 &= ~LOCKLPM5;

  // Configure ADC
  ADCCTL0 |= ADCSHT_2 | ADCON;                       // 16ADCclks, ADC ON
  ADCCTL1 |= ADCSHP | ADCCONSEQ_0 | ADCSSEL_1;       // ADC clock ACLK, sampling timer, s/w trig.,single sequence
  ADCCTL2 &= ~ADCRES_1;                              // 8-bit conversion results

  P2OUT |=  STATUS_LED;                     // STATUS LED on

  __delay_cycles(10);

  int adc_ch1_results;
  int adc_ch2_results;

  // Configure Timer Peripheral for PWM
  TB0CCR0 = 140;                            // PWM Period
  TB0CCTL1 = OUTMOD_7;                      // CCR1 reset/set
  TB0CCR1 = 0;                             // CCR1 PWM duty cycle
  TB0CCTL2 = OUTMOD_7;                      // CCR2 reset/set
  TB0CCR2 = 0;                              // CCR2 PWM duty cycle

  TB0CTL = TBSSEL__SMCLK | MC__UP | TBCLR |ID_1;  // SMCLK, up mode, clear TBR, Divide clk by 2

  while(1)
  {
      ADCCTL0 &= ~(ADCENC | ADCSC);
      ADCMCTL0 = ADCINCH_1 + ADCSREF_0;       // A1; Vref=AVCC
      ADCCTL0 |= ADCENC | ADCSC;              // Sampling and conversion start
      while(ADCCTL1 & ADCBUSY);               // Wait for conversion complete
      adc_ch2_results = ADCMEM0/1.5;              // Put ADC value into variable before loading into TB0CCR2

      ADCCTL0 &= ~(ADCENC | ADCSC);
      ADCMCTL0 = ADCINCH_0 + ADCSREF_0;       // A0; Vref=AVCC
      ADCCTL0 |= ADCENC | ADCSC;              // Sampling and conversion start
      while(ADCCTL1 & ADCBUSY);               // Wait for conversion complete
      adc_ch1_results = ADCMEM0/1.5;

      TB0CCR2 = adc_ch2_results;
      TB0CCR1 = adc_ch1_results;                      // Put ADC value into TB0CCR1
}
}
